import{d as u,eu as _,H as v,b as r,et as c,e as i,u as b,ev as a,aN as f,ew as m,ex as S,ey as g,x as k}from"./outputWidgets.b13a87c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="22af4d91-dfa0-4e81-a126-4dfc2c6938a2",e._sentryDebugIdIdentifier="sentry-dbid-22af4d91-dfa0-4e81-a126-4dfc2c6938a2")}catch{}})();const w=u({__name:"Modal",props:{containerStyle:{},headerStyle:{},contentStyle:{}},emits:["open","close"],setup(e,{expose:t,emit:n}){const p=_(),y=()=>{o.isOpened=!0,n("open")},d=()=>{o.isOpened=!1,n("close")};t({open:y,close:d});const o=v({isOpened:!1});return(s,l)=>(r(),c("div",{class:g(["background",o.isOpened&&"visible"]),onClick:d},[i("div",{class:"container",style:a(s.containerStyle),onClick:l[0]||(l[0]=S(()=>{},["stop"]))},[b(p).header?(r(),c("div",{key:0,class:"header",style:a(s.headerStyle)},[f(s.$slots,"header",{},void 0,!0)],4)):m("",!0),i("div",{class:"content",style:a(s.contentStyle)},[f(s.$slots,"content",{},void 0,!0)],4)],4)],2))}});const I=k(w,[["__scopeId","data-v-24f739ca"]]);export{I as M};
//# sourceMappingURL=Modal.66296973.js.map
