import{d as b,ez as g,eA as v,r as k,b as r,c as s,w as a,u as e,f as d,ew as i}from"./outputWidgets.b13a87c2.js";import{S as h,L as w}from"./SmartConsole.a7d3a3a2.js";import{a as B}from"./asyncComputed.02afd50e.js";import{H as C}from"./hooks.b78152bb.js";import{_ as H}from"./SaveButton.vue_vue_type_script_setup_true_lang.cfe351b9.js";import{_ as I}from"./DocsButton.vue_vue_type_script_setup_true_lang.db34d7f2.js";import{B as S}from"./BaseLayout.a36af3c6.js";import{_ as T,a as x}from"./HookSettings.vue_vue_type_script_setup_true_lang.b51f73b4.js";import{c as A}from"./index.3d7f8177.js";import{A as _,T as D}from"./TabPane.3cb0210e.js";import"./forms.c0c5fcb0.js";import"./activeRecord.f5a2d19d.js";import"./pubsub.dab46576.js";import"./dashes.4926394c.js";import"./index.98e61e8e.js";import"./jobs.a3ced864.js";import"./workspaces.f986af40.js";import"./icons.76c1fe8b.js";import"./Title.6f86755a.js";import"./index.1b5bc05c.js";import"./uuid.8237862c.js";import"./ant-design.b9e555b3.js";import"./index.c32ce6af.js";import"./index.55a2786b.js";import"./index.73746068.js";import"./index.fbf04eaa.js";import"./Form.e21e0d73.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[m]="eb0428de-dd27-4699-ad4d-63e9c6d9dbf3",n._sentryDebugIdIdentifier="sentry-dbid-eb0428de-dd27-4699-ad4d-63e9c6d9dbf3")}catch{}})();const ne=b({__name:"HookEditor",setup(n){const m=g(),l=v(),p=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=B(()=>C.get(l.params.hookPath)),c=w.create();return(R,f)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(A),{key:0,title:e(t).title,onBack:y},{footer:a(()=>[d(e(D),{"active-key":o.value,"onUpdate:activeKey":f[0]||(f[0]=u=>o.value=u)},{default:a(()=>[d(e(_),{key:"test",tab:"Test"}),d(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[d(I,{path:"hooks"}),o.value==="settings"?(r(),s(H,{key:0,model:e(t)},null,8,["model"])):i("",!0)]),_:1},8,["title"])):i("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:p,hook:e(t),"log-service":e(c)},null,8,["hook","log-service"])):i("",!0),e(t)&&o.value==="settings"?(r(),s(x,{key:1,hook:e(t)},null,8,["hook"])):i("",!0)]),footer:a(()=>{var u;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(c),onRestart:(u=p.value)==null?void 0:u.runHook},null,8,["log-service","onRestart"])):i("",!0)]}),_:1}))}});export{ne as default};
//# sourceMappingURL=HookEditor.b13d6210.js.map
