import{x as o,a,b as i,c,g as d,h as p,_,i as u,T as l,j as f,P as h,C as m,M as y,s as b,k as s,l as g,m as v,n as w,p as I}from"./outputWidgets.b13a87c2.js";import{u as k}from"./index.fa2d5075.js";import"./pubsub.dab46576.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f063fcc9-c574-472a-936b-a7d3049d433b",e._sentryDebugIdIdentifier="sentry-dbid-f063fcc9-c574-472a-936b-a7d3049d433b")}catch{}})();const x={};function A(e,t){const r=a("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=o(x,[["render",A]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.b7b04b02.js"),["assets/Player.b7b04b02.js","assets/index.98e61e8e.js","assets/outputWidgets.b13a87c2.js","assets/outputWidgets.8ce475af.css","assets/uuid.8237862c.js","assets/broker.6522c718.js","assets/index.fa2d5075.js","assets/pubsub.dab46576.js","assets/executeJs.7971ae06.js","assets/icons.76c1fe8b.js","assets/CircularLoading.9771b42b.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.1c65f36f.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.2eaacc3c.js","assets/Steps.998aa76d.css","assets/Modal.66296973.js","assets/Modal.5aaf8eba.css","assets/executeJs.9c4b02ee.css","assets/WidgetsFrame.023caee0.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.77e4b71e.js","assets/broker.ac4594bd.css","assets/DashPlayer.8df1cc2e.js","assets/geometryUtils.6d566989.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.02afd50e.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}(async()=>{await k();const e=u({render:()=>g(D)});l.init(),f(e,n),P.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",m),e.component("Markdown",y),e.component("Message",b),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.3bde94d0.js.map
