import{d as a,r as d,o as l,eP as c,b as u,et as f,eC as p,eN as y}from"./outputWidgets.b13a87c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9319736e-0e28-4534-8d81-7956b4e71802",e._sentryDebugIdIdentifier="sentry-dbid-9319736e-0e28-4534-8d81-7956b4e71802")}catch{}})();const m=a({__name:"ActionButton",props:{action:{},displayName:{}},emits:["click"],setup(e,{emit:n}){const o=e,s=d(null);return l(()=>{s.value&&o.action.setElement(s.value),c.addAction(o.action)}),(i,t)=>(u(),f("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=r=>n("click")),onKeydown:t[1]||(t[1]=y(r=>n("click"),["enter"]))},p(i.displayName),545))}});export{m as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.77e4b71e.js.map
