import{S as p}from"./Sidebar.db74fc07.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.7bd6f741.js";import{F as d,G as l,H as u}from"./icons.76c1fe8b.js";import{d as b,eA as f,J as g,a as _,b as y,c as v,w as e,f as a}from"./outputWidgets.b13a87c2.js";import{a as w}from"./asyncComputed.02afd50e.js";import"./console.d76c010c.js";import{O as z}from"./organization.2e5c7a70.js";import"./index.b8915c7f.js";import{B as h}from"./BaseLayout.a36af3c6.js";import"./Tooltip.a469d789.js";import"./logo.084e5d7c.js";import"./index.957937c4.js";import"./Title.6f86755a.js";import"./index.55a2786b.js";import"./index.3d7f8177.js";import"./index.98e61e8e.js";import"./Form.e21e0d73.js";import"./index.c4d59e95.js";import"./dayjs.2e90d17d.js";import"./index.fbf04eaa.js";import"./index.7011a200.js";import"./TabPane.3cb0210e.js";import"./index.0345671f.js";import"./index.24360d49.js";import"./index.c32ce6af.js";import"./index.73746068.js";import"./index.7dcc157a.js";import"./index.0b99f8ef.js";import"./index.1b5bc05c.js";import"./gateway.f581ef9f.js";import"./activeRecord.f5a2d19d.js";import"./pubsub.dab46576.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="61462419-3ae2-4f02-bda9-c2730d9f22f4",o._sentryDebugIdIdentifier="sentry-dbid-61462419-3ae2-4f02-bda9-c2730d9f22f4")}catch{}})();const eo=b({__name:"Organization",setup(o){const i=f().params.organizationId,{result:r}=w(()=>z.get(i)),n=g(()=>r.value?[{label:"My organizations",path:"/organizations"},{label:r.value.name,path:`/organizations/${r.value.id}`}]:void 0),m=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const s=_("router-view");return y(),v(h,null,{navbar:e(()=>[a(c,{breadcrumb:n.value},null,8,["breadcrumb"])]),sidebar:e(()=>[a(p,{class:"sidebar",sections:m})]),content:e(()=>[a(s)]),_:1})}}});export{eo as default};
//# sourceMappingURL=Organization.efa9a9fa.js.map
