import{d as u,eA as f,J as b,b as y,c as _,u as g}from"./outputWidgets.b13a87c2.js";import{a as w}from"./asyncComputed.02afd50e.js";import"./console.d76c010c.js";import{M as m}from"./member.bec819e5.js";import"./index.b8915c7f.js";import{_ as I}from"./CrudView.vue_vue_type_script_setup_true_lang.cf244ae9.js";import"./index.98e61e8e.js";import"./Form.e21e0d73.js";import"./Title.6f86755a.js";import"./index.3d7f8177.js";import"./index.55a2786b.js";import"./index.c4d59e95.js";import"./dayjs.2e90d17d.js";import"./index.fbf04eaa.js";import"./index.7011a200.js";import"./TabPane.3cb0210e.js";import"./index.0345671f.js";import"./index.24360d49.js";import"./index.c32ce6af.js";import"./index.73746068.js";import"./index.7dcc157a.js";import"./index.0b99f8ef.js";import"./index.1b5bc05c.js";import"./index.957937c4.js";import"./gateway.f581ef9f.js";import"./activeRecord.f5a2d19d.js";import"./pubsub.dab46576.js";import"./icons.76c1fe8b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="bca02805-bf21-4393-834f-4a6dcc49355c",e._sentryDebugIdIdentifier="sentry-dbid-bca02805-bf21-4393-834f-4a6dcc49355c")}catch{}})();const V=u({__name:"Members",setup(e){const r=f().params.organizationId,n=[{key:"email",label:"Email"}],s=async t=>{await m.create(r,t.email),c()},{loading:p,result:l,refetch:c}=w(()=>m.list(r)),d=b(()=>{var t,i;return{columns:[{name:"Email"},{name:"Role"}],rows:(i=(t=l.value)==null?void 0:t.map(a=>({key:a.email,cells:[{text:a.email},{text:a.role}]})))!=null?i:[]}});return(t,i)=>(y(),_(I,{"entity-name":"members",loading:g(p),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:d.value,"create-button-text":"Add members",fields:n,onCreate:s},null,8,["loading","table"]))}});export{V as default};
//# sourceMappingURL=Members.abaa9164.js.map
